@@ -12,6 +12,8 @@ $ #OpaqueMove
 # Opaque Window Moving
 $ #FullMax
 # Full Maximization
+$ #IgnoreShaded
+# Ignore Shaded Windows
 $ #FocusNew
 # Focus New Windows
 $ #FocusLast
@@ -40,3 +42,9 @@ $ #TopBottom
 # Top to Bottom
 $ #BottomTop
 # Bottom to Top
+$ #NoDithering
+# Do not dither images
+$ #OrderedDithering
+# Use fast dither
+$ #FloydSteinbergDithering
+# Use high-quality dither
