@@ -40,3 +40,9 @@ $ #TopBottom
 # Oppefra
 $ #BottomTop
 # Nedefra
+$ #NoDithering
+# Do not dither images
+$ #OrderedDithering
+# Use fast dither
+$ #FloydSteinbergDithering
+# Use high-quality dither
