@@ -7,7 +7,8 @@ $ #DISPLAYRequiresArg
 $ #WarnDisplaySet
 # advarsel: kunne ikke stte variablen 'DISPLAY'\n
 $ #Usage
-# Blackbox %s: (c) 1997 - 2000 Brad Hughes\n\n\
+# Blackbox %s : (c) 2001 - 2002 Sean 'Shaleh' Perry\n\
+  \t\t\t 1997 - 2000, 2002 Brad Hughes\n\n\
   -display <string>\t\tbrug skrm tilslutning.\n\
   -rc <string>\t\t\tbrug alternativ resource fil.\n\
   -version\t\t\tvis versionsnummer og afslut.\n\
@@ -15,7 +16,5 @@ $ #Usage
 $ #CompileOptions
 # Kompileret med:\n\
   Debugging\t\t\t%s\n\
-  Interlacing:\t\t\t%s\n\
   Shape:\t\t\t%s\n\
-  Slit:\t\t\t\t%s\n\
   8bpp Ordered Dithering:\t%s\n\n
