@@ -40,3 +40,9 @@ $ #TopBottom
 # Von oben nach unten
 $ #BottomTop
 # Von unten nach oben
+$ #NoDithering
+# Do not dither images
+$ #OrderedDithering
+# Use fast dither
+$ #FloydSteinbergDithering
+# Use high-quality dither
