@@ -40,3 +40,9 @@ $ #TopBottom
 # De Arriba Abajo
 $ #BottomTop
 # De Abajo Arriba
+$ #NoDithering
+# Do not dither images
+$ #OrderedDithering
+# Use fast dither
+$ #FloydSteinbergDithering
+# Use high-quality dither
