@@ -7,7 +7,8 @@ $ #DISPLAYRequiresArg
 $ #WarnDisplaySet
 # hoiatus: ei saanud mrata keskonna muutujat 'DISPLAY'\n
 $ #Usage
-# Blackbox %s: (c) 1997 - 2000 Brad Hughes\n\n\
+# Blackbox %s : (c) 2001 - 2002 Sean 'Shaleh' Perry\n\
+  \t\t\t 1997 - 2000, 2002 Brad Hughes\n\n\
   -display <string>\t\tkasuta displei hendust.\n\
   -rc <string>\t\t\tkasuta alternatiivseid resursse.\n\
   -version\t\t\tnita versiooninumber ja vlju.\n\
@@ -15,7 +16,5 @@ $ #Usage
 $ #CompileOptions
 # Kompileerimisoptsioonid:\n\
   Debuggimine\t\t\t%s\n\
-  Pimimine:\t\t\t%s\n\
   Kuju:\t\t\t%s\n\
-  Pragu:\t\t\t\t%s\n\
   8bpp mratud teravustamine:\t%s\n\n
