@@ -40,3 +40,9 @@ $ #TopBottom
 # De haut en bas
 $ #BottomTop
 # De bas en haut
+$ #NoDithering
+# Do not dither images
+$ #OrderedDithering
+# Use fast dither
+$ #FloydSteinbergDithering
+# Use high-quality dither
