@@ -40,3 +40,9 @@ $ #TopBottom
 # Fentrl lefele
 $ #BottomTop
 # Lentrl felfele
+$ #NoDithering
+# Do not dither images
+$ #OrderedDithering
+# Use fast dither
+$ #FloydSteinbergDithering
+# Use high-quality dither
