@@ -13,5 +13,5 @@ $ #MapRequest
 # BlackboxWindow::mapRequestEvent() per 0x%lx\n
 $ #UnmapNotify
 # BlackboxWindow::unmapNotifyEvent() per 0x%lx\n
-$ #UnmapNotifyReparent
-# BlackboxWindow::unmapnotifyEvent: reparent 0x%lx a root\n
+$ #ReparentNotify
+# BlackboxWindow::reparentNotifyEvent: reparent 0x%lx a 0x%lx\n
