@@ -38,3 +38,9 @@ $ #TopBottom
 #  Ʒ
 $ #BottomTop
 # Ʒ 
+$ #NoDithering
+# Do not dither images
+$ #OrderedDithering
+# Use fast dither
+$ #FloydSteinbergDithering
+# Use high-quality dither
