@@ -40,3 +40,9 @@ $ #TopBottom
 # No Augas uz Leju
 $ #BottomTop
 # No Lejas uz Augu
+$ #NoDithering
+# Do not dither images
+$ #OrderedDithering
+# Use fast dither
+$ #FloydSteinbergDithering
+# Use high-quality dither
