@@ -40,3 +40,9 @@ $ #TopBottom
 # Van boven naar beneden
 $ #BottomTop
 # Van beneden naar boven
+$ #NoDithering
+# Do not dither images
+$ #OrderedDithering
+# Use fast dither
+$ #FloydSteinbergDithering
+# Use high-quality dither
