@@ -40,3 +40,9 @@ $ #TopBottom
 # De sus in jos
 $ #BottomTop
 # De jos in sus
+$ #NoDithering
+# Do not dither images
+$ #OrderedDithering
+# Use fast dither
+$ #FloydSteinbergDithering
+# Use high-quality dither
