@@ -40,3 +40,9 @@ $ #TopBottom
 # Zhora nadol
 $ #BottomTop
 # Zdola nahor
+$ #NoDithering
+# Do not dither images
+$ #OrderedDithering
+# Use fast dither
+$ #FloydSteinbergDithering
+# Use high-quality dither
