@@ -40,3 +40,9 @@ $ #TopBottom
 # Uppifrn
 $ #BottomTop
 # Nerifrn
+$ #NoDithering
+# Do not dither images
+$ #OrderedDithering
+# Use fast dither
+$ #FloydSteinbergDithering
+# Use high-quality dither
