@@ -36,3 +36,9 @@ $ #TopBottom
 # stten aaa
 $ #BottomTop
 # Alttan ste
+$ #NoDithering
+# Do not dither images
+$ #OrderedDithering
+# Use fast dither
+$ #FloydSteinbergDithering
+# Use high-quality dither
