@@ -36,3 +36,9 @@ $ #TopBottom
 # ѤWܤU 
 $ #BottomTop
 # ѤUܤW 
+$ #NoDithering
+# Do not dither images
+$ #OrderedDithering
+# Use fast dither
+$ #FloydSteinbergDithering
+# Use high-quality dither
