@@ -1,7 +1,8 @@
-// -*- mode: C++; indent-tabs-mode: nil; -*-
+// -*- mode: C++; indent-tabs-mode: nil; c-basic-offset: 2; -*-
 // Icon.cc for Blackbox - an X11 Window manager
-// Copyright (c) 2001 - 2002 Sean 'Shaleh' Perry <shaleh@debian.org>
-// Copyright (c) 1997 - 2000 Brad Hughes (bhughes@tcac.net)
+// Copyright (c) 2001 - 2005 Sean 'Shaleh' Perry <shaleh@debian.org>
+// Copyright (c) 1997 - 2000, 2002 - 2005
+//         Bradley T Hughes <bhughes at trolltech.com>
 //
 // Permission is hereby granted, free of charge, to any person obtaining a
 // copy of this software and associated documentation files (the "Software"),
@@ -21,37 +22,24 @@
 // FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 // DEALINGS IN THE SOFTWARE.
 
-#ifdef    HAVE_CONFIG_H
-#  include "../config.h"
-#endif // HAVE_CONFIG_H
-
-#include "i18n.hh"
 #include "Iconmenu.hh"
 #include "Screen.hh"
 #include "Window.hh"
 
+#include <Unicode.hh>
 
-Iconmenu::Iconmenu(BScreen *scrn) : Basemenu(scrn) {
-  setInternalMenu();
 
-  setLabel(i18n(IconSet, IconIcons, "Icons"));
-  update();
+Iconmenu::Iconmenu(bt::Application &app, unsigned int screen,
+                   BScreen *bscreen)
+  : bt::Menu(app, screen), _bscreen(bscreen)
+{
+  setAutoDelete(false);
+  setTitle(bt::toUnicode("Iconified Windows"));
+  showTitle();
 }
 
 
-void Iconmenu::itemSelected(int button, unsigned int index) {
-  if (button != 1)
-    return;
-
-  if (index < getScreen()->getIconCount()) {
-    BlackboxWindow *win = getScreen()->getIcon(index);
-
-    if (win) {
-      win->deiconify();
-      win->setInputFocus();
-    }
-  }
-
-  if (! (getScreen()->getWorkspacemenu()->isTorn() || isTorn()))
-    hide();
+void Iconmenu::itemClicked(unsigned int id, unsigned int) {
+  BlackboxWindow * const win = _bscreen->icon(id);
+  win->activate();
 }
